@@ -3,4 +3,4 @@
 #     "/Users/osso/src/inspire",
 # ]
 
-USE_CONSOLE = False
+# USE_CONSOLE = False
