@@ -43,6 +43,8 @@ DIRS = {
     'bft': 'etc/bibformat/format_templates',
     'bfo': 'etc/bibformat/output_formats',
     'html': None,
+    'kb': None,
+    'cfg': None,
 }
 
 SPECIAL_DIRS = [
@@ -109,6 +111,12 @@ SPECIAL_DIRS = [
     (ur"modules/webjournal/lib/widgets/.+\.py$", 'lib/python/invenio/bibformat_elements'),
     (ur"modules/webstyle/etc/.+\.css$", 'var/www/ckeditor'),
     (ur"webstyle/.+\.css$", 'var/www/img'),
+
+    # DocExtract KBs
+    (ur"modules/docextract/etc/.+\.kb$", 'etc/docextract'),
+
+    # Configuration files
+    (ur"modules/bibrank/etc/.+\.cfg$", 'etc/bibrank'),
 ]
 
 SPECIAL_DIRS_RE = [(re.compile(pattern , re.U|re.I), dest_dir) for pattern, dest_dir in SPECIAL_DIRS]
@@ -166,3 +174,4 @@ IGNORE_FILES_RE = {re.compile(pattern , re.U|re.I) for pattern in IGNORE_FILES}
 
 CONFIG_FILENAME = 'invenio.conf'
 LOCAL_CONFIG_FILENAME = 'invenio-local.conf'
+AUTOTOOLS_CONFIG_FILENAME = 'invenio-autotools.conf'
