@@ -6,7 +6,6 @@ import optparse
 import socket
 import traceback
 import logging
-import re
 from itertools import chain
 
 try:
@@ -44,13 +43,17 @@ def get_extension(filename):
         return ''
 
 
-def valid_extension(filename, dirs=config.DIRS):
+def valid_extension(filename, dirs=None):
     """Checks the extension of the file to see if we should monitor it"""
+    if dirs is None:
+        dirs = config.DIRS
     return get_extension(filename) in dirs.keys()
 
 
-def generate_invenio_files_list(invenio_path=config.SRC_PATH):
+def generate_invenio_files_list(invenio_path=None):
     """Generates the list of all the source files to be monitored"""
+    if invenio_path is None:
+        invenio_path = config.SRC_PATH
     if isinstance(invenio_path, basestring):
         invenio_path = [invenio_path]
 
@@ -68,8 +71,11 @@ def generate_invenio_files_list(invenio_path=config.SRC_PATH):
                 [os.path.join(config.INSTALL_PATH, 'etc/invenio-local.conf')])
 
 
-def select_destination_path(filename, install_path=config.INSTALL_PATH,
-                                                            dests=config.DIRS):
+def select_destination_path(filename, install_path=None, dests=None):
+    if install_path is None:
+        install_path = config.INSTALL_PATH
+    if dests is None:
+        dests = config.DIRS
     dest = None
 
     rel_path = filename
@@ -157,7 +163,8 @@ def reloader_loop(files, reloader=None, interval=1):
                     _log('info', ' * Detected change in %r' % filename)
 
                 if os.path.basename(filename) in (config.CONFIG_FILENAME,
-                                                 config.LOCAL_CONFIG_FILENAME):
+                                                 config.LOCAL_CONFIG_FILENAME,
+                                                 config.AUTOTOOLS_CONFIG_FILENAME):
                     has_conf_changes = True
 
                 has_changes = True
@@ -196,15 +203,17 @@ class Reloader(object):
         self.worker_pid = spawn_server(self.options, self.server_socket)
 
 
-def print_traceback(sig, frame):
+def print_traceback(sig, frame):  # pylint: disable=W0613
     traceback.print_stack(frame)
 
 
-def start_server(options, server_socket, static_files=config.STATIC_FILES):
+def start_server(options, server_socket, static_files=None):
     """Start a new http server
 
     Called by the worker
     """
+    if static_files is None:
+        static_files = config.STATIC_FILES
     # We only import wsgi here because this import some invenio components
     # and we do not want anything imported from invenio in the parent
     import wsgi
@@ -229,7 +238,7 @@ def start_server(options, server_socket, static_files=config.STATIC_FILES):
         def pdb_on_error(f, *args, **kwargs):
             try:
                 return f(*args, **kwargs)
-            except:  # pylint: disable-msg=W0702
+            except:  # pylint: disable=W0702
                 # We catch on purpose all errors for debugging
                 pdb.post_mortem()
 
@@ -265,7 +274,7 @@ def spawn_server(options, server_socket):
     if pid == 0:
         try:
             start_server(options, server_socket)
-        except:  # pylint: disable-msg=W0702
+        except:  # pylint: disable=W0702
             # We catch on purpose all errors for debugging
             print traceback.format_exc()[:-1]
             _log('info', ' * Worker crashed')
